@@ -3,12 +3,12 @@
  *
  * kscd -- A simple CD player for the KDE project
  *
- * $Id: configdlg.cpp,v 1.19.2.1 1999/04/02 19:24:08 dfaure Exp $
- * 
- * Copyright (C) 1997 Bernd Johannes Wuebben 
+ * $Id: configdlg.cpp,v 1.32 2000/08/09 17:51:25 bieker Exp $
+ *
+ * Copyright (C) 1997 Bernd Johannes Wuebben
  * wuebben@math.cornell.edu
  *
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
  * License as published by the Free Software Foundation; either
@@ -28,54 +28,52 @@
 
 
 #include "configdlg.h"
+#include <klocale.h>
 #define XOFF 75
 #define YOFF 30
 //#define XOFF 0
 //#define YOFF 0
 
-extern KApplication *mykapp;
-
-
-ConfigDlg::ConfigDlg(QWidget *parent=0, struct configstruct *data = 0,const char *name=0)
+ConfigDlg::ConfigDlg(QWidget *parent, struct configstruct *data,const char *name)
   : QDialog(parent, name)
 {
 
   configdata.background_color = black;
   configdata.led_color = green;
   configdata.tooltips = true;
-  configdata.cd_device ="/dev/cdrom";
-  configdata.mailcmd = "mail -s \"%s\" ";
+  configdata.cd_device = QString::fromLatin1("/dev/cdrom");
+  configdata.mailcmd = QString::fromLatin1("mail -s \"%s\" ");
   configdata.docking = true;
   configdata.autoplay = false;
-  configdata.autodock = false;
   configdata.stopexit = true;
   configdata.ejectonfinish = false;
 
-  if(data){
-    configdata.background_color = data->background_color;
-    configdata.led_color = data->led_color;
-    configdata.tooltips = data->tooltips;
-    configdata.cd_device = data->cd_device;
-    configdata.mailcmd = data->mailcmd;
-    configdata.browsercmd = data->browsercmd;
-    configdata.use_kfm = data->use_kfm;
-    configdata.docking = data->docking;
-    configdata.autoplay = data->autoplay;
-    configdata.autodock = data->autodock;
-    configdata.stopexit = data->stopexit;
-    configdata.ejectonfinish = data->ejectonfinish;
-  }
+  if(data)
+    {
+      configdata.background_color = data->background_color;
+      configdata.randomonce = true;
+      configdata.led_color = data->led_color;
+      configdata.tooltips = data->tooltips;
+      configdata.cd_device = data->cd_device;
+      configdata.mailcmd = data->mailcmd;
+      configdata.browsercmd = data->browsercmd;
+      configdata.use_kfm = data->use_kfm;
+      configdata.docking = data->docking;
+      configdata.autoplay = data->autoplay;
+      configdata.stopexit = data->stopexit;
+      configdata.ejectonfinish = data->ejectonfinish;
+    }
 
   colors_changed = false;
 
-  setCaption(klocale->translate("Configure kscd"));
+  configdata.randomonce = data->randomonce;
+  setCaption(i18n("Configure kscd"));
 
   box = new QGroupBox(this, "box");
   box->setGeometry(10,10,520,420);
 
-  label1 = new QLabel(this);
+  label1 = new QLabel(i18n("LED Color:"), this);
   label1->setGeometry(20+XOFF,25+YOFF,135,25);
-  label1->setText(klocale->translate("LED Color:"));
   label1->setFixedSize( label1->sizeHint() );
 
   qframe1 = new QFrame(this);
@@ -85,12 +83,11 @@ ConfigDlg::ConfigDlg(QWidget *parent=0, struct configstruct *data = 0,const char
 
   button1 = new QPushButton(this);
   button1->setGeometry(255+XOFF,25+YOFF,100,25);
-  button1->setText(klocale->translate("Change"));
+  button1->setText(i18n("Change"));
   connect(button1,SIGNAL(clicked()),this,SLOT(set_led_color()));
 
-  label2 = new QLabel(this);
+  label2 = new QLabel(i18n("Background Color:"),this);
   label2->setGeometry(20+XOFF,55+YOFF,135,25);
-  label2->setText(klocale->translate("Background Color:"));
 
   qframe2 = new QFrame(this);
   qframe2->setGeometry(155+XOFF,55+YOFF,30,25);
@@ -99,18 +96,17 @@ ConfigDlg::ConfigDlg(QWidget *parent=0, struct configstruct *data = 0,const char
 
   button2 = new QPushButton(this);
   button2->setGeometry(255+XOFF,55+YOFF,100,25);
-  button2->setText(klocale->translate("Change"));
+  button2->setText(i18n("Change"));
   connect(button2,SIGNAL(clicked()),this,SLOT(set_background_color()));
 
-  label5 = new QLabel(this);
+  label5 = new QLabel(i18n("CDROM Device:"), this);
   label5->setGeometry(20+XOFF,85+YOFF,135,25);
-  label5->setText(klocale->translate("CDROM Device:"));
 
   cd_device_edit = new QLineEdit(this);
   cd_device_edit->setGeometry(155+XOFF,85+YOFF,200,25);
   cd_device_edit->setText(configdata.cd_device);
-  connect(cd_device_edit,SIGNAL(textChanged(const char*)),
-	  this,SLOT(device_changed(const char*)));  
+  connect(cd_device_edit,SIGNAL(textChanged(const QString &)),
+	  this,SLOT(device_changed(const QString &)));
 
 #if defined(sun) || defined(__sun__) || defined(__osf__) || defined(ultrix) || defined(__ultrix)
 
@@ -121,25 +117,25 @@ ConfigDlg::ConfigDlg(QWidget *parent=0, struct configstruct *data = 0,const char
 
   label6 = new QLabel(this);
   label6->setGeometry(20+XOFF,115+YOFF,135,25);
-  label6->setText(klocale->translate("Unix mail command:"));
+  label6->setText(i18n("Unix mail command:"));
 
   mail_edit = new QLineEdit(this);
   mail_edit->setGeometry(155+XOFF,115+YOFF,200,25);
   mail_edit->setText(configdata.mailcmd);
-  connect(mail_edit,SIGNAL(textChanged(const char*)),
-	  this,SLOT(mail_changed(const char*)));  
+  connect(mail_edit,SIGNAL(textChanged(const QString &)),
+	  this,SLOT(mail_changed(const QString &)));
 
-  browserbox = new  QButtonGroup(klocale->translate("WWW-Browser"),this,"wwwbox");
+  browserbox = new  QButtonGroup(i18n("WWW-Browser"),this,"wwwbox");
 //  browserbox->setGeometry(20+XOFF,145+YOFF,338,130);
   browserbox->setGeometry(20+XOFF,145+YOFF,338, 95);
-  kfmbutton = new QRadioButton(klocale->translate("Use kfm as Browser"),
+  kfmbutton = new QRadioButton(i18n("Use Konqueror as Browser"),
 			       browserbox,"kfmbutton");
   kfmbutton->move(10,20);
   kfmbutton->adjustSize();
   kfmbutton->setChecked(configdata.use_kfm);
   connect(kfmbutton,SIGNAL(clicked()),this,SLOT(kfmbutton_clicked()));
 
-  custombutton = new QRadioButton(klocale->translate("Use Custom Browser:"),
+  custombutton = new QRadioButton(i18n("Use Custom Browser:"),
 				  browserbox,"custombutton");
   custombutton->move(10,40);
   custombutton->adjustSize();
@@ -151,173 +147,183 @@ ConfigDlg::ConfigDlg(QWidget *parent=0, struct configstruct *data = 0,const char
   custom_edit->setEnabled(!configdata.use_kfm);
   custom_edit->setGeometry(30,60,198+70,25);
 
-  ttcheckbox = new QCheckBox(klocale->translate("Show Tool Tips"), 
+  ttcheckbox = new QCheckBox(i18n("Show Tool Tips"),
 			     this, "tooltipscheckbox");
   ttcheckbox->setGeometry(30+XOFF,245+YOFF,135, 15);
   ttcheckbox->setFixedSize( ttcheckbox->sizeHint() );
   ttcheckbox->setChecked(configdata.tooltips);
   connect(ttcheckbox,SIGNAL(clicked()),this,SLOT(ttclicked()));
 
-  dockcheckbox = new QCheckBox(klocale->translate("Enable KPanel Docking"), 
+  dockcheckbox = new QCheckBox(i18n("Enable KPanel Docking"),
 			       this, "dockcheckbox");
   dockcheckbox->setGeometry(30+XOFF,265+YOFF,200, 15);
   dockcheckbox->setFixedSize( dockcheckbox->sizeHint() );
   dockcheckbox->setChecked(configdata.docking);
   connect(dockcheckbox,SIGNAL(clicked()),this,SLOT(dockclicked()));
 
-  cdAutoPlayCB = new QCheckBox(klocale->translate("Play on Tray Close"),
+  cdAutoPlayCB = new QCheckBox(i18n("Play on Tray Close"),
                                this, "cdAutoPlayCB");
   cdAutoPlayCB->setGeometry(30+XOFF, 285+YOFF, 200, 15);
   cdAutoPlayCB->setFixedSize( cdAutoPlayCB->sizeHint() );
   cdAutoPlayCB->setChecked(configdata.autoplay);
   connect(cdAutoPlayCB, SIGNAL(clicked()), this, SLOT(autoPlayClicked()));
 
-  dockOnMinimizeCB = new QCheckBox(klocale->translate("AutoDock on Minimize"),
-                                   this, "dockOnMinimizeCB");
-  dockOnMinimizeCB->setGeometry(30+XOFF, 305+YOFF, 200, 15);
-  dockOnMinimizeCB->setFixedSize( dockOnMinimizeCB->sizeHint() );
-  dockOnMinimizeCB->setChecked(configdata.autodock);
-  connect(dockOnMinimizeCB, SIGNAL(clicked()), this, SLOT(dockOnMinimizeClicked()));
-  dockOnMinimizeCB->setEnabled(configdata.docking);
-
-  stopOnExitCB = new QCheckBox(klocale->translate("Stop Playing on Exit"),
+  stopOnExitCB = new QCheckBox(i18n("Stop Playing on Exit"),
                                this, "stopOnExitCB");
   stopOnExitCB->setGeometry(30+XOFF, 325+YOFF, 200, 15);
   stopOnExitCB->setFixedSize( stopOnExitCB->sizeHint() );
   stopOnExitCB->setChecked(configdata.stopexit);
   connect(stopOnExitCB, SIGNAL(clicked()), this, SLOT(stopOnExitClicked()));
 
-  ejectOnFinishCB = new QCheckBox(klocale->translate("Eject on Finish"),
+  ejectOnFinishCB = new QCheckBox(i18n("Eject on Finish"),
                                   this, "ejectOnFinishCB");
   ejectOnFinishCB->setGeometry(30+XOFF, 345+YOFF, 200, 15);
   ejectOnFinishCB->setFixedSize( ejectOnFinishCB->sizeHint() );
   ejectOnFinishCB->setChecked(configdata.ejectonfinish);
   connect(ejectOnFinishCB, SIGNAL(clicked()), this, SLOT(ejectOnFinishClicked()));
 
-  
+
+  /* koz: Added a configure option to select the unique random play mode, */
+  /* or the traditional random mode */
+  randomOnceCB = new QCheckBox(i18n("Random is Shuffle"),
+			     this, "randomOnceCB");
+  randomOnceCB->setGeometry(30+XOFF,365+YOFF,200,15);
+  randomOnceCB->setFixedSize(randomOnceCB->sizeHint());
+  randomOnceCB->setChecked(configdata.randomonce);
+  connect(randomOnceCB,SIGNAL(clicked()),this,SLOT(randomOnceClicked()));
+
   button3 = new QPushButton(this);
   button3->setGeometry( 420, 400, 90, 25 );
   //button3->setGeometry(255+XOFF,340+YOFF,100,25);
-  button3->setText(klocale->translate("Help"));
+  button3->setText(i18n("Help"));
   connect(button3,SIGNAL(clicked()),this,SLOT(help()));
 }
 
 
-void ConfigDlg::custombutton_clicked(){
-
+void 
+ConfigDlg::custombutton_clicked()
+{
     configdata.use_kfm = false;
     custom_edit->setEnabled(!configdata.use_kfm);
-}
+} // custombutton_clicked
 
 
-void ConfigDlg::kfmbutton_clicked(){
-
+void 
+ConfigDlg::kfmbutton_clicked()
+{
     configdata.use_kfm = true;
     custom_edit->setEnabled(!configdata.use_kfm);
-}
+} // kfmbutton_clicked
 
 
-void ConfigDlg::okbutton() {
+void 
+ConfigDlg::okbutton() 
+{
+} // okbutton
 
-
-
-}
-
-void ConfigDlg::device_changed(const char* dev) {
+void 
+ConfigDlg::device_changed(const QString &dev) {
 
   configdata.cd_device = dev;
-}
+} // device_changed
 
-void ConfigDlg::mail_changed(const char* dev) {
+void 
+ConfigDlg::mail_changed(const QString &dev) {
 
   configdata.mailcmd = dev;
-}
+} // mail_changed
 
-void ConfigDlg::ttclicked(){
+void 
+ConfigDlg::ttclicked(){
 
   if(ttcheckbox->isChecked())
     configdata.tooltips = TRUE;
   else
     configdata.tooltips = FALSE;
+} // ttclicked
 
-}
-
-void ConfigDlg::dockclicked(){
+void 
+ConfigDlg::dockclicked(){
 
     if(dockcheckbox->isChecked()){
-        dockOnMinimizeCB->setEnabled(true);
         configdata.docking = TRUE;
     }else{
-        dockOnMinimizeCB->setEnabled(false);
         configdata.docking = FALSE;
     }
-}
+} // dockclicked
 
-void ConfigDlg::autoPlayClicked(){
+void 
+ConfigDlg::autoPlayClicked(){
     if(cdAutoPlayCB->isChecked())
         configdata.autoplay = TRUE;
     else
         configdata.autoplay = FALSE;
-}
+} // autoPlayClicked
 
-void ConfigDlg::dockOnMinimizeClicked()
-{
-    if(dockOnMinimizeCB->isChecked())
-        configdata.autodock = TRUE;
-    else
-        configdata.autodock = FALSE;
-}
 
-void ConfigDlg::stopOnExitClicked()
+void 
+ConfigDlg::stopOnExitClicked()
 {
     if(stopOnExitCB->isChecked())
         configdata.stopexit = TRUE;
     else
         configdata.stopexit = FALSE;
-}
+} // stopOnExitClicked
 
-void ConfigDlg::ejectOnFinishClicked()
+void 
+ConfigDlg::ejectOnFinishClicked()
 {
     if(ejectOnFinishCB->isChecked())
         configdata.ejectonfinish = TRUE;
     else
         configdata.ejectonfinish = FALSE;
-}
+} // ejectOnFinishClicked
 
-void ConfigDlg::help(){
+void 
+ConfigDlg::help()
+{
+    kapp->invokeHTMLHelp("kscd/kscd.html","");
+} // help
 
-  if(mykapp)
-    mykapp->invokeHTMLHelp("kscd/kscd.html","");
-}
-
-void ConfigDlg::cancelbutton() {
+void 
+ConfigDlg::cancelbutton() 
+{
   reject();
-}
-
-void ConfigDlg::set_led_color(){
-
+} // cancelbutton
 
+void 
+ConfigDlg::set_led_color()
+{
   KColorDialog::getColor(configdata.led_color);
   qframe1->setBackgroundColor(configdata.led_color);
+} // set_led_color
 
-
-}
-
-void ConfigDlg::set_background_color(){
+void 
+ConfigDlg::set_background_color()
+{
 
   KColorDialog::getColor(configdata.background_color);
   qframe2->setBackgroundColor(configdata.background_color);
+} // set_background_color
 
-}
-
-struct configstruct * ConfigDlg::getData(){
+void 
+ConfigDlg::randomOnceClicked()
+{
+  if(randomOnceCB->isChecked())
+    configdata.randomonce = TRUE;
+  else
+    configdata.randomonce = FALSE;
+} // randomOnceClicked
 
+struct configstruct * 
+ConfigDlg::getData()
+{
   configdata.browsercmd = custom_edit->text();
   return &configdata;
-
-}
+} // getData
 
 #include "configdlg.moc"
 
 
 
+
