@@ -1,7 +1,7 @@
 /*
    Kscd - A simple cd player for the KDE Project
 
-   $Id: kscd.h,v 1.24 1998/12/16 15:21:09 ettrich Exp $
+   $Id: kscd.h,v 1.44 2000/08/30 04:19:20 dfoerste Exp $
 
    Copyright (c) 1997 Bernd Johannes Wuebben math.cornell.edu
 
@@ -29,19 +29,20 @@
 
 #include "bwlednum.h"
 
-#include <qpushbt.h>
+
+#include <qpushbutton.h>
 #include <qlabel.h>
 #include <qdialog.h>
-#include <qapp.h>
+#include <qapplication.h>
 #include <qtimer.h>
 #include <qbitmap.h>
-#include <qcombo.h>
-#include <qmsgbox.h>
-#include <qscrbar.h>
+#include <qcombobox.h>
+#include <qscrollbar.h>
 #include <qslider.h>
-#include <qtabdlg.h>
+#include <qtabdialog.h>
 #include <qtooltip.h>
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
+
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -68,9 +69,9 @@
 #include <sys/mount.h>
 #endif
 
-#ifdef linux
+#ifdef __linux__
 #include <mntent.h>
-#define KSCDMAGIC 1
+#define KSCDMAGIC 0
 #endif
 
 #include "cddb.h"
@@ -82,8 +83,8 @@
 #include <kapp.h>
 #include <kprocess.h>
 
-struct configstruct{
-
+struct configstruct
+{
   QColor led_color;
   QColor background_color;
   bool   tooltips;
@@ -93,16 +94,19 @@ struct configstruct{
   bool	use_kfm;
   bool	docking;
   bool  autoplay;
-  bool autodock;
   bool stopexit;
   bool ejectonfinish;
+  bool randomonce;
 };
 
-struct mgconfigstruct{
-
+struct mgconfigstruct
+{
   int width;
   int height;
   int brightness;
+  int fadeMode;
+  bool pointsAreDiamonds;
+  double starSize;
 };
 
 
@@ -118,6 +122,7 @@ public slots:
     void smtpMessageSent(void);
     void smtpError(int);
     void magicdone(KProcess*);
+    void magicslot();
     void magicslot(int);
     void togglequeryled();
     void cddb_done();
@@ -126,6 +131,7 @@ public slots:
     void cddb_failed();
     void setToolTips();
     void randomSelected();
+
     void readSettings();
     void writeSettings();
     void setColors();
@@ -137,6 +143,8 @@ public slots:
     void fwdClicked();
     void bwdClicked();
     void quitClicked();
+    void loopOn();
+    void loopOff();
     void loopClicked();
     void cdMode();
     void ejectClicked();
@@ -161,9 +169,10 @@ public slots:
     void purchases(int);
     void information(int);
     void showPopup();
-    void dockClicked();
 
-    void doSM();
+  //    void doSM();
+
+    void make_random_list(); /* koz: 15/01/00 */
 
 private:
     CDDBSetup       *setup;
@@ -179,6 +188,7 @@ private:
     QPushButton	    *fwdPB;
     QPushButton	    *bwdPB;
     QPushButton	    *dockPB;
+    QPushButton     *magicPB;
     QPushButton	    *replayPB;
     QPushButton	    *ejectPB;
     QPushButton	    *aboutPB;
@@ -201,25 +211,27 @@ private:
     QPushButton 	*optionsbutton;
     QPushButton 	*shufflebutton;
     QPushButton 	*cddbbutton;
-    QPushButton	*volLA;
+    QPushButton	        *volLA;
     QTimer		*timer;
     QTimer		*titlelabeltimer;
     QTimer		*queryledtimer;
     QTimer		*initimer;
     QTimer		*cycletimer;
-    QComboBox	*songListCB;
+    QComboBox	        *songListCB;
     QSlider		*volSB;
 
-    KProcess*             magicproc;
-    int		volChnl;
-    int		mixerFd;
+    KProcess*           magicproc;
+    int	                volChnl;
+    int		        mixerFd;
     int 	        volume;
-    int magic_width;
-    int magic_height;
-    int magic_brightness;
+    int                 magic_width;
+    int                 magic_height;
+    int                 magic_brightness;
+    bool                magic_pointsAreDiamonds;
     QFrame 		*backdrop;
-    LedLamp        *queryled;
-    KConfig 	*config;
+    LedLamp             *queryled;
+    LedLamp             *loopled;
+    KConfig 	        *config;
     bool 		tooltips;
     bool 		randomplay ;
     bool 		looping;
@@ -227,18 +239,25 @@ private:
     QString		cycle_str;
     bool 		volstartup;
     bool 		cddrive_is_ok;
+    bool                have_new_cd;
     int 		time_display_mode;
-    QString cd_device_str;
+    QString             cd_device_str;
 
-    QPushButton     *makeButton( int, int, int, int, const char * );
+    QPushButton         *makeButton( int, int, int, int, const QString& );
 
+
+    int                 smallPtSize();
     void		initWorkMan();
     //	void		checkMount();
 
     void		drawPanel();
     void		cleanUp();
     void		loadBitmaps();
-    void 	 	setLEDs(QString symbols);
+    void 	 	setLEDs(const QString& symbols);
+  /**
+   * select a random track from the current disc.
+   *
+   */
     int 	        randomtrack();
 
 //TODO get rid of the mixe stuff
@@ -247,10 +266,10 @@ private:
 
 // These are the variables from workbone
 
-	int 		sss;
-	int 		sel_stat;
-	int 		dly;
-	int 		fastin;
+        int 		sss;
+        int 		sel_stat;
+        int  		dly;
+        int 		fastin;
 	int 		scmd;
 	int 		tmppos;
 	int 		save_track;
@@ -259,35 +278,35 @@ private:
 	FILE 		*fp;
 
 	CDDB 		cddb;
-	QStrList        querylist;
-	QStrList        pathlist;
-	QStrList        discidlist;
-	QStrList	tracktitlelist;
-	QStrList	playlist;
+	QStringList        querylist;
+	QStringList        pathlist;
+	QStringList        discidlist;
+	QStringList	tracktitlelist;
+	QStringList	playlist;
 	int		playlistpointer;
-	QStrList	extlist;
+	QStringList	extlist;
 	int		revision;
 	QString	        category;
 	QString	        xmcd_data;
 	QString         cddbbasedir;
-	QStrList	cddbserverlist;
+	QStringList	cddbserverlist;
 	QString		current_server;
 	QString	        mailcmd;
         QString  	submitaddress;
-        QStrList cddbsubmitlist;
+        QStringList        cddbsubmitlist;
 	QString  	browsercmd;
 	bool		cddb_remote_enabled;
 	bool 		use_kfm;
         bool            docking;
         bool            autoplay;
-        bool autodock;
-        bool stopexit;
-        bool ejectonfinish;
+        bool            stopexit;
+        bool            ejectonfinish;
+        bool            randomonce;
 
 	bool 		cddb_inexact_sentinel;
         bool            updateDialog;
-        bool ejectedBefore;
-        bool currentlyejected;
+        bool            ejectedBefore;
+        bool            currentlyejected;
 public:
 
 	KSCD( QWidget *parent = 0, const char *name = 0 );
@@ -300,10 +319,9 @@ protected:
     //    void focusOutEvent(QFocusEvent *e);
     void playtime();
     void setupPopups();
-    void startBrowser(char* querystring);
+    void startBrowser(const QString& querystring);
     bool getArtist(QString& artist);
-    void get_pathlist(QStrList& _patlist);
-
+    void get_pathlist(QStringList& _patlist);
 };
 
 
